@@ -4,9 +4,9 @@ This function get a string as input if input is one digit add a zero
 :param input_string: input digit az string
 :type input_string:str
 :return: modified output as str
->>> import coverage
->>> cov=coverage.Coverage()
->>> cov.start()
+>>> import os
+>>> import random
+>>> import sys
 >>> from art import *
 >>> font_list()
 3-d :
@@ -104,13 +104,15 @@ banner3 :
    ##    ##       ##    ##    ##
    ##    ########  ######     ##
 <BLANKLINE>
-banner3-D :
- _               _
-| |_   ___  ___ | |_
-| __| / _ \/ __|| __|
-| |_ |  __/\__ \| |_
- \__| \___||___/ \__|
-<BLANKLINE>
+banner3-d :
+'########:'########::'######::'########:
+... ##..:: ##.....::'##... ##:... ##..::
+::: ##:::: ##::::::: ##:::..::::: ##::::
+::: ##:::: ######:::. ######::::: ##::::
+::: ##:::: ##...:::::..... ##:::: ##::::
+::: ##:::: ##:::::::'##::: ##:::: ##::::
+::: ##:::: ########:. ######::::: ##::::
+:::..:::::........:::......::::::..:::::
 <BLANKLINE>
 banner4 :
 .########.########..######..########
@@ -121,6 +123,16 @@ banner4 :
 ....##....##.......##....##....##...
 ....##....########..######.....##...
 <BLANKLINE>
+barbwire :
+  ><<                     ><<
+  ><<                     ><<
+><>< ><   ><<     ><<<< ><>< ><
+  ><<   ><   ><< ><<      ><<
+  ><<  ><<<<< ><<  ><<<   ><<
+  ><<  ><            ><<  ><<
+   ><<   ><<<<   ><< ><<   ><<
+<BLANKLINE>
+<BLANKLINE>
 basic :
 d888888b d88888b .d8888. d888888b
 `~~88~~' 88'     88'  YP `~~88~~'
@@ -139,6 +151,29 @@ bell :
   \__/ `.___, \___.'  \__/
 <BLANKLINE>
 <BLANKLINE>
+big :
+ _               _
+| |             | |
+| |_   ___  ___ | |_
+| __| / _ \/ __|| __|
+| |_ |  __/\__ \| |_
+ \__| \___||___/ \__|
+<BLANKLINE>
+<BLANKLINE>
+<BLANKLINE>
+bigchief :
+_________________________
+<BLANKLINE>
+<BLANKLINE>
+--_/_-----__----__---_/_-
+  /     /___)  (_ `  /
+_(_ ___(___ __(__)__(_ __
+<BLANKLINE>
+<BLANKLINE>
+<BLANKLINE>
+binary :
+01110100 01100101 01110011 01110100
+<BLANKLINE>
 block :
 <BLANKLINE>
  .----------------.  .----------------.  .----------------.  .----------------.
@@ -163,12 +198,40 @@ _|_|_|_|    _|_|      _|_|_|  _|_|_|_|
 <BLANKLINE>
 <BLANKLINE>
 <BLANKLINE>
+bubble :
+  _    _    _    _
+ / \  / \  / \  / \
+( t )( e )( s )( t )
+ \_/  \_/  \_/  \_/
+<BLANKLINE>
 bulbhead :
  ____  ____  ___  ____
 (_  _)( ___)/ __)(_  _)
   )(   )__) \__ \  )(
  (__) (____)(___/ (__)
 <BLANKLINE>
+calgphy2 :
+<BLANKLINE>
+<BLANKLINE>
+<BLANKLINE>
+    #                              #
+   ##                             ##
+   ##                             ##
+ ########    /##       /###     ########
+########    / ###     / #### / ########
+   ##      /   ###   ##  ###/     ##
+   ##     ##    ### ####          ##
+   ##     ########    ###         ##
+   ##     #######       ###       ##
+   ##     ##              ###     ##
+   ##     ####    /  /###  ##     ##
+   ##      ######/  / #### /      ##
+    ##      #####      ###/        ##
+<BLANKLINE>
+<BLANKLINE>
+<BLANKLINE>
+<BLANKLINE>
+<BLANKLINE>
 caligraphy :
 <BLANKLINE>
 <BLANKLINE>
@@ -267,6 +330,23 @@ ___ ____ ____ ___
  |  |___ ___]  |
 <BLANKLINE>
 <BLANKLINE>
+cygnet :
+<BLANKLINE>
+ .       .
+-|-.-,.--|-
+ '-`'--' '-
+<BLANKLINE>
+<BLANKLINE>
+diamond :
+  /\\                     /\\
+  /\\                     /\\
+/\/\ /\   /\\     /\\\\ /\/\ /\
+  /\\   /\   /\\ /\\      /\\
+  /\\  /\\\\\ /\\  /\\\   /\\
+  /\\  /\            /\\  /\\
+   /\\   /\\\\   /\\ /\\   /\\
+<BLANKLINE>
+<BLANKLINE>
 digital :
 +-++-++-++-+
 |t||e||s||t|
@@ -328,6 +408,13 @@ drpepper :
   |_|  \___./__/  |_|
 <BLANKLINE>
 <BLANKLINE>
+eftifont :
+<BLANKLINE>
+||  _  _ ||
+| ]/o\(c'| ]
+L| \( \_)L|
+<BLANKLINE>
+<BLANKLINE>
 eftirobot :
  _            _
 ( )          ( )
@@ -336,6 +423,18 @@ eftirobot :
 /_\  \(  /__)/_\
 <BLANKLINE>
 <BLANKLINE>
+eftitalic :
+<BLANKLINE>
+  /7  __  __  /7
+ /_7,'o/ (c' /_7
+//  |_( /__)//
+<BLANKLINE>
+<BLANKLINE>
+eftiwater :
+ _        _
+ )L __ __ )L
+(( (('_))((
+<BLANKLINE>
 epic :
 _________ _______  _______ _________
 \__   __/(  ____ \(  ____ \\__   __/
@@ -347,6 +446,12 @@ _________ _______  _______ _________
    )_(   (_______/\_______)   )_(
 <BLANKLINE>
 <BLANKLINE>
+fourtops :
+ |       |
+~|~/~/(~~|~
+ | \/__) |
+<BLANKLINE>
+<BLANKLINE>
 fuzzy :
  .-.              .-.
 .' `.            .' `.
@@ -356,6 +461,15 @@ fuzzy :
 <BLANKLINE>
 <BLANKLINE>
 <BLANKLINE>
+goofy :
+_        __        ___       ___        __
+(__    __) \    ___)  )  ____) (__    __)
+   |  |     |  (__   (  (___      |  |
+   |  |     |   __)   \___  \     |  |
+   |  |     |  (___   ____)  )    |  |
+___|  |____/       )_(      (_____|  |____
+<BLANKLINE>
+<BLANKLINE>
 graffiti :
   __                     __
 _/  |_   ____    _______/  |_
@@ -364,6 +478,26 @@ _/  |_   ____    _______/  |_
  |__|   \___  >/____  > |__|
             \/      \/
 <BLANKLINE>
+hollywood :
+<BLANKLINE>
+         /'                               /'
+     --/'--                           --/'--
+     /'         ____      ____        /'
+   /'         /'    )   /'    )--   /'
+ /'         /(___,/'   '---,      /'
+(__        (________ (___,/      (__
+<BLANKLINE>
+<BLANKLINE>
+<BLANKLINE>
+<BLANKLINE>
+invita :
+<BLANKLINE>
+<BLANKLINE>
+_/_   _  _  _/_
+(__ _(/_/_)_(__
+<BLANKLINE>
+<BLANKLINE>
+<BLANKLINE>
 isometric1 :
       ___           ___           ___           ___
      /\  \         /\  \         /\  \         /\  \
@@ -416,6 +550,24 @@ isometric4 :
    \__\/          \  \:\        \  \::/      \__\/
                    \__\/         \__\/
 <BLANKLINE>
+italic :
+<BLANKLINE>
+_/  _   _ _/
+/  (- _)  /
+<BLANKLINE>
+<BLANKLINE>
+jazmine :
+<BLANKLINE>
+  o                  o
+  8                  8
+ o8P .oPYo. .oPYo.  o8P
+  8  8oooo8 Yb..     8
+  8  8.       'Yb.   8
+  8  `Yooo' `YooP'   8
+::..::.....::.....:::..:
+::::::::::::::::::::::::
+::::::::::::::::::::::::
+<BLANKLINE>
 larry3d :
  __                       __
 /\ \__                   /\ \__
@@ -427,6 +579,70 @@ larry3d :
 <BLANKLINE>
 <BLANKLINE>
 <BLANKLINE>
+lcd :
+<BLANKLINE>
+  |                 |
+ -+-   -       -   -+-
+  |   |/       \    |
+   -   --      -     -
+<BLANKLINE>
+<BLANKLINE>
+lean :
+<BLANKLINE>
+   _/                                   _/
+_/_/_/_/       _/_/         _/_/_/   _/_/_/_/
+ _/         _/_/_/_/     _/_/         _/
+_/         _/               _/_/     _/
+ _/_/       _/_/_/     _/_/_/         _/_/
+<BLANKLINE>
+<BLANKLINE>
+<BLANKLINE>
+letters :
+tt                 tt
+tt      eee   sss  tt
+tttt  ee   e s     tttt
+tt    eeeee   sss  tt
+ tttt  eeeee     s  tttt
+              sss
+<BLANKLINE>
+lockergnome :
+ :|             :|
+:::| :~~/ <::< :::|
+ :|  :::, >::>  :|
+<BLANKLINE>
+madrid :
+|-         |-
+|  /=\ /== |
+\= \=  ==/ \=
+<BLANKLINE>
+<BLANKLINE>
+marquee :
+  .::                     .::
+  .::                     .::
+.:.: .:   .::     .:::: .:.: .:
+  .::   .:   .:: .::      .::
+  .::  .::::: .::  .:::   .::
+  .::  .:            .::  .::
+   .::   .::::   .:: .::   .::
+<BLANKLINE>
+<BLANKLINE>
+maxfour :
+ |       |
+~|~/~/(~~|~
+ | \/__) |
+<BLANKLINE>
+<BLANKLINE>
+mike :
+  _   _     _
+   | |/ //   |
+<BLANKLINE>
+<BLANKLINE>
+mini :
+<BLANKLINE>
+_|_  _   _ _|_
+ |_ (/_ _>  |_
+<BLANKLINE>
+<BLANKLINE>
 nancyj :
   dP                       dP
   88                       88
@@ -437,6 +653,43 @@ d8888P .d8888b. .d8888b. d8888P
 <BLANKLINE>
 <BLANKLINE>
 <BLANKLINE>
+nancyj-fancy :
+  dP                       dP
+  88                       88
+d8888P .d8888b. .d8888b. d8888P
+  88   88ooood8 Y8ooooo.   88
+  88   88.  ...       88   88
+  dP   `88888P' `88888P'   dP
+<BLANKLINE>
+<BLANKLINE>
+nancyj-underlined :
+  dP                       dP
+  88                       88
+d8888P .d8888b. .d8888b. d8888P
+  88   88ooood8 Y8ooooo.   88
+  88   88.  ...       88   88
+  dP   `88888P' `88888P'   dP
+oooooooooooooooooooooooooooooooo
+<BLANKLINE>
+<BLANKLINE>
+nipples :
+  {__                     {__
+  {__                     {__
+{_{_ {_   {__     {____ {_{_ {_
+  {__   {_   {__ {__      {__
+  {__  {_____ {__  {___   {__
+  {__  {_            {__  {__
+   {__   {____   {__ {__   {__
+<BLANKLINE>
+<BLANKLINE>
+o8 :
+  o8                             o8
+o888oo  ooooooooo8  oooooooo8  o888oo
+ 888   888oooooo8  888ooooooo   888
+ 888   888                 888  888
+  888o   88oooo888 88oooooo88    888o
+<BLANKLINE>
+<BLANKLINE>
 ogre :
  _               _
 | |_   ___  ___ | |_
@@ -445,6 +698,74 @@ ogre :
  \__| \___||___/ \__|
 <BLANKLINE>
 <BLANKLINE>
+pawp :
+<BLANKLINE>
+ _                 _
+(_)_   ____  ____ (_)_
+(___) (____)(____)(___)
+(_)  (_)_(_)(_)__ (_)
+(_)_ (__)__  _(__)(_)_
+ (__) (____)(____) (__)
+<BLANKLINE>
+<BLANKLINE>
+<BLANKLINE>
+peaks :
+  /^^                     /^^
+  /^^                     /^^
+/^/^ /^   /^^     /^^^^ /^/^ /^
+  /^^   /^   /^^ /^^      /^^
+  /^^  /^^^^^ /^^  /^^^   /^^
+  /^^  /^            /^^  /^^
+   /^^   /^^^^   /^^ /^^   /^^
+<BLANKLINE>
+<BLANKLINE>
+pebbles :
+<BLANKLINE>
+<BLANKLINE>
+  O                 O
+ oOo               oOo
+  o   .oOo. .oOo    o
+  O   OooO' `Ooo.   O
+  o   O         O   o
+  `oO `OoO' `OoO'   `oO
+<BLANKLINE>
+<BLANKLINE>
+<BLANKLINE>
+pepper :
+<BLANKLINE>
+_/_ _   __/_
+/  /_'_\ /
+<BLANKLINE>
+<BLANKLINE>
+poison :
+<BLANKLINE>
+@@@@@@@  @@@@@@@@   @@@@@@   @@@@@@@
+@@@@@@@  @@@@@@@@  @@@@@@@   @@@@@@@
+  @@!    @@!       !@@         @@!
+  !@!    !@!       !@!         !@!
+  @!!    @!!!:!    !!@@!!      @!!
+  !!!    !!!!!:     !!@!!!     !!!
+  !!:    !!:            !:!    !!:
+  :!:    :!:           !:!     :!:
+   ::     :: ::::  :::: ::      ::
+   :     : :: ::   :: : :       :
+<BLANKLINE>
+<BLANKLINE>
+puffy :
+ _                 _
+( )_              ( )_
+| ,_)   __    ___ | ,_)
+| |   /'__`\/',__)| |
+| |_ (  ___/\__, \| |_
+`\__)`\____)(____/`\__)
+<BLANKLINE>
+<BLANKLINE>
+<BLANKLINE>
+pyramid :
+  ^    ^    ^    ^
+ /t\  /e\  /s\  /t\
+<___><___><___><___>
+<BLANKLINE>
 rectangles :
 <BLANKLINE>
  _              _
@@ -465,6 +786,8 @@ roman :
 <BLANKLINE>
 <BLANKLINE>
 <BLANKLINE>
+rot13 :
+grfg
 rounded :
 <BLANKLINE>
    _                   _
@@ -482,6 +805,23 @@ rowancap :
 dMP       dMMMMMP     VMMMP"    dMP
 <BLANKLINE>
 <BLANKLINE>
+rozzo :
+  d8                   d8
+ d88    ,e e,   dP"Y  d88
+d88888 d88 88b C88b  d88888
+ 888   888   ,  Y88D  888
+ 888    "YeeP" d,dP   888
+<BLANKLINE>
+<BLANKLINE>
+<BLANKLINE>
+sblood :
+ @@@@@@@ @@@@@@@@  @@@@@@ @@@@@@@
+   @@!   @@!      !@@       @@!
+   @!!   @!!!:!    !@@!!    @!!
+   !!:   !!:          !:!   !!:
+    :    : :: ::: ::.: :     :
+<BLANKLINE>
+<BLANKLINE>
 script :
 <BLANKLINE>
 <BLANKLINE>
@@ -504,6 +844,11 @@ shadow :
 \__| \___| ____/ \__|
 <BLANKLINE>
 <BLANKLINE>
+short :
+|- _  _|-
+|_(/__\|_
+<BLANKLINE>
+<BLANKLINE>
 slant :
    __                  __
   / /_  ___    _____  / /_
@@ -512,6 +857,63 @@ slant :
 \__/  \___/ /____/  \__/
 <BLANKLINE>
 <BLANKLINE>
+slide :
+ #|                #|
+##HH|  #H|   #HH| ##HH|
+ #|   ##HH| ##H|   #|
+ #|   ##       H|  #|
+ #H|   #HH| ##H|   #H|
+<BLANKLINE>
+<BLANKLINE>
+slscript :
+<BLANKLINE>
+ _/_        _/_
+ /   _  _   /
+<__ </_/_)_<__
+<BLANKLINE>
+<BLANKLINE>
+<BLANKLINE>
+small :
+ _             _
+| |_  ___  ___| |_
+|  _|/ -_)(_-<|  _|
+ \__|\___|/__/ \__|
+<BLANKLINE>
+smisome1 :
+    ___       ___       ___       ___
+   /\  \     /\  \     /\  \     /\  \
+   \:\  \   /::\  \   /::\  \    \:\  \
+   /::\__\ /::\:\__\ /\:\:\__\   /::\__\
+  /:/\/__/ \:\:\/  / \:\:\/__/  /:/\/__/
+  \/__/     \:\/  /   \::/  /   \/__/
+             \/__/     \/__/
+<BLANKLINE>
+smkeyboard :
+ ____  ____  ____  ____
+||t ||||e ||||s ||||t ||
+||__||||__||||__||||__||
+|/__\||/__\||/__\||/__\|
+<BLANKLINE>
+smscript :
+<BLANKLINE>
+_|_  _  ,  _|_
+ |  |/ / \_ |
+ |_/|_/ \/  |_/
+<BLANKLINE>
+<BLANKLINE>
+smshadow :
+ |               |
+  _|   -_) (_-<   _|
+\__| \___| ___/ \__|
+<BLANKLINE>
+<BLANKLINE>
+smslant :
+  __             __
+ / /_ ___   ___ / /_
+/ __// -_) (_-</ __/
+\__/ \__/ /___/\__/
+<BLANKLINE>
+<BLANKLINE>
 speed :
 _____               _____
 __  /______ __________  /_
@@ -520,6 +922,14 @@ _  __/_  _ \__  ___/_  __/
 \__/  \___/ /____/  \__/
 <BLANKLINE>
 <BLANKLINE>
+stampatello :
+.          .
+|- ,-. ,-. |-
+|  |-' `-. |
+`' `-' `-' `'
+<BLANKLINE>
+<BLANKLINE>
+<BLANKLINE>
 standard :
  _               _
 | |_   ___  ___ | |_
@@ -556,6 +966,12 @@ stop :
  \___) \____)(___/  \___)
 <BLANKLINE>
 <BLANKLINE>
+straight :
+<BLANKLINE>
+|_  _  _ |_
+|_ (- _) |_
+<BLANKLINE>
+<BLANKLINE>
 swan :
 <BLANKLINE>
 <BLANKLINE>
@@ -577,6 +993,18 @@ t)tTTT                 t)tTTT
 <BLANKLINE>
 <BLANKLINE>
 <BLANKLINE>
+tengwar :
+             .dP'
+           dP'
+<BLANKLINE>
+`Yb.d888b   'Yb   .d888b.  `Yb.d888b
+ 88'    8Y   88   8'   `Yb  88'    8Y
+ 88     8P   88   Yb.   88  88     8P
+ 88   ,dP   .8P       .dP   88   ,dP
+ 88                 .dP'    88
+ 88               .dP'      88
+.8P                        .8P
+<BLANKLINE>
 thick :
  w               w
 w8ww .d88b d88b w8ww
@@ -597,6 +1025,15 @@ _|_ _  __|_
  | (/__\ |
 <BLANKLINE>
 <BLANKLINE>
+tinker-toy :
+ o           o
+ |           |
+-o- o-o o-o -o-
+ |  |-'  \   |
+ o  o-o o-o  o
+<BLANKLINE>
+<BLANKLINE>
+<BLANKLINE>
 tombstone :
  ___ __,  _, ___
   |  |_  (_   |
@@ -645,32 +1082,63 @@ weird :
 |__  |__   __/ |__
 <BLANKLINE>
 <BLANKLINE>
->>> aprint_test()
+>>> tprint("test",font = "block243")
+<BLANKLINE>
+  _|                            _|
+_|_|_|_|    _|_|      _|_|_|  _|_|_|_|
+  _|      _|_|_|_|  _|_|        _|
+  _|      _|            _|_|    _|
+    _|_|    _|_|_|  _|_|_|        _|_|
+<BLANKLINE>
+<BLANKLINE>
+<BLANKLINE>
+>>> art_list()
 100$
 [̲̅$̲̅(̲̅ιοο̲̅)̲̅$̲̅]
 ******************************
+3
+ᕙ༼ ,,ԾܫԾ,, ༽ᕗ
+******************************
+5
+ᕙ༼ ,,இܫஇ,, ༽ᕗ
+******************************
 airplane1
  ‛¯¯٭٭¯¯(▫▫)¯¯٭٭¯¯’
 ******************************
 airplane2
 ✈
 ******************************
-angry_face
+angry face
 (⋟﹏⋞)
 ******************************
+angry2
+( ͠° ͟ʖ ͡°)﻿
+******************************
+ankush
+︻デ┳═ー*----*
+******************************
 arrow
 »»---------------------►
 ******************************
+atish
+(| - _ - |)
+******************************
 awesome
 <:3 )~~~
 ******************************
+bagel
+nln >_< nln
+******************************
 bear
 ʕ•ᴥ•ʔ
 ******************************
-big_eyes
+bee
+¸.·´¯`·¸¸.·´¯`·.¸.-<\^}0=:
+******************************
+big eyes
 ⺌∅‿∅⺌
 ******************************
-big_nose
+big nose
 ˚∆˚
 ******************************
 bird
@@ -682,33 +1150,39 @@ birds
 boobs
 (.)(.)
 ******************************
-boom_box
+boom box
 ♫♪.ılılıll|̲̅̅●̲̅̅|̲̅̅=̲̅̅|̲̅̅●̲̅̅|llılılı.♫♪
 ******************************
 bullshit
 |3ᵕᶦᶦᶳᶣᶨᶵ
 ******************************
+bunny
+(\_/)
+******************************
 butterfly
 Ƹ̵̡Ӝ̵̨̄Ʒ
 ******************************
-car_race
+car race
 |[●▪▪●]|
 ******************************
-care_crowd
+care crowd
 (-(-_(-_-)_-)-)
 ******************************
 cassette
 |[●▪▪●]|
 ******************************
+cat face
+⦿⽘⦿
+******************************
+cat smile
+≧◔◡◔≦﻿
+******************************
 cat1
 =^..^=
 ******************************
 cat2
 龴ↀ◡ↀ龴
 ******************************
-cat_face
-⦿⽘⦿
-******************************
 caterpillar
 ,/\,/\,/\,/\,/\,/\,o
 ******************************
@@ -721,6 +1195,9 @@ cheer
 chess
 ♞▀▄▀▄♝▀▄
 ******************************
+chess pieces
+♚ ♛ ♜ ♝ ♞ ♟ ♔ ♕ ♖ ♗ ♘ ♙
+******************************
 cigarette
 (____((____________()~~~
 ******************************
@@ -730,19 +1207,34 @@ c[_]
 cry
  (╯︵╰,)
 ******************************
-cute_cat
+crying
+Ỏ̷͖͈̞̩͎̻̫̫̜͉̠̫͕̭̭̫̫̹̗̹͈̼̠̖͍͚̥͈̮̼͕̠̤̯̻̥̬̗̼̳̤̳̬̪̹͚̞̼̠͕̼̠̦͚̫͔̯̹͉͉̘͎͕̼̣̝͙̱̟̹̩̟̳̦̭͉̮̖̭̣̣̞̙̗̜̺̭̻̥͚͙̝̦̲̱͉͖͉̰̦͎̫̣̼͎͍̠̮͓̹̹͉̤̰̗̙͕͇͔̱͕̭͈̳̗̭͔̘̖̺̮̜̠͖̘͓̳͕̟̠̱̫̤͓͔̘̰̲͙͍͇̙͎̣̼̗̖͙̯͉̠̟͈͍͕̪͓̝̩̦̖̹̼̠̘̮͚̟͉̺̜͍͓̯̳̱̻͕̣̳͉̻̭̭̱͍̪̩̭̺͕̺̼̥̪͖̦̟͎̻̰_Ỏ̷͖͈̞̩͎̻̫̫̜͉̠̫͕̭̭̫̫̹̗̹͈̼̠̖͍͚̥͈̮̼͕̠̤̯̻̥̬̗̼̳̤̳̬̪̹͚̞̼̠͕̼̠̦͚̫͔̯̹͉͉̘͎͕̼̣̝͙̱̟̹̩̟̳̦̭͉̮̖̭̣̣̞̙̗̜̺̭̻̥͚͙̝̦̲̱͉͖͉̰̦͎̫̣̼͎͍̠̮͓̹̹͉̤̰̗̙͕͇͔̱͕̭͈̳̗̭͔̘̖̺̮̜̠͖̘͓̳͕̟̠̱̫̤͓͔̘̰̲͙͍͇̙͎̣̼̗̖͙̯͉̠̟͈͍͕̪͓̝̩̦̖̹̼̠̘̮͚̟͉̺̜͍͓̯̳̱̻͕̣̳͉̻̭̭̱͍̪̩̭̺͕̺̼̥̪͖̦̟͎̻̰
+******************************
+cthulhu
+^(;,;)^
+******************************
+cute cat
 ^⨀ᴥ⨀^
 ******************************
 dagger
 cxxx|;:;:;:;:;:;:;:;>
 ******************************
+decorate
+▂▃▅▇█▓▒░۩۞۩        ۩۞۩░▒▓█▇▅▃▂
+******************************
+dice
+[: :]
+******************************
 dog
 ˁ˚ᴥ˚ˀ
 ******************************
+dummy
+<-|-'_'-|->
+******************************
 elephant
 °j°m
 ******************************
-eye_closed
+eye closed
  (╯_╰)
 ******************************
 eyes
@@ -757,30 +1249,57 @@ finger1
 finger2
 ┌∩┐(◣_◢)┌∩┐
 ******************************
+fish swim
+¸.·´¯`·.´¯`·.¸¸.·´¯`·.¸><(((º>
+******************************
 fish1
 ><(((('>
 ******************************
 fish2
 ><>
 ******************************
-fish_swim
-¸.·´¯`·.´¯`·.¸¸.·´¯`·.¸><(((º>
+formula1 car
+\ō͡≡o˞̶
+******************************
+fox
+-^^,--,~
+******************************
+fu
+(ಠ_ಠ)┌∩┐
+******************************
+fuck you
+nlm (-_-) mln
+******************************
+ghost
+‹’’›(Ͼ˳Ͽ)‹’’›
 ******************************
 glasses
 -@-@-
 ******************************
+glasses2
+ᒡ◯ᵔ◯ᒢ
+******************************
+guitar
+c====(=#O| ) ~~ ♬·¯·♩¸¸♪·¯·♫¸
+******************************
 gun
 ︻╦╤─
 ******************************
 hairstyle
 ⨌⨀_⨀⨌
 ******************************
+hal
+@_'-'
+******************************
 happy
  ۜ\(סּںסּَ` )/ۜ
 ******************************
 happy2
 ⎦˚◡˚⎣
 ******************************
+head shot
+->~∑≥_≤)
+******************************
 headphone
 d[-_-]b
 ******************************
@@ -793,10 +1312,13 @@ heart2
 help
 ٩(͡๏̯͡๏)۶
 ******************************
+homer
+(_8(|)
+******************************
 house
 __̴ı̴̴̡̡̡ ̡͌l̡̡̡ ̡͌l̡*̡̡ ̴̡ı̴̴̡ ̡̡͡|̲̲̲͡͡͡ ̲▫̲͡ ̲̲̲͡͡π̲̲͡͡ ̲̲͡▫̲̲͡͡ ̲|̡̡̡ ̡ ̴̡ı̴̡̡ ̡͌l̡̡̡̡.___
 ******************************
-hug_me
+hug me
 (っ◕‿◕)っ
 ******************************
 human
@@ -808,31 +1330,52 @@ hybrix
 inlove
 (✿ ♥‿♥)
 ******************************
+killer
+(⌐■_■)--︻╦╤─ - - - (╥﹏╥)
+******************************
+king
+-_-
+******************************
+kirby
+(つ -‘ _ ‘- )つ
+******************************
+kiss
+(o'3'o)
+******************************
 knife
 )xxxxx[;;;;;;;;;>
 ******************************
 koala
 @( * O * )@
 ******************************
+kokain
+ ̿ ̿' ̿'\̵͇̿̿\з=(•̪●)=ε/̵͇̿̿/'̿''̿ ̿
+******************************
 linqan
 :Q___
 ******************************
-looking_face
+looking face
 ô¿ô
 ******************************
-love_in_my_eye
+love in my eye
 (♥_♥)
 ******************************
-love_you
+love you
 »-(¯`·.·´¯)-><-(¯`·.·´¯)-«
 ******************************
+mango
+) _ _ __/°°¬
+******************************
 message1
 (¯`·._.·(¯`·._.·  ·._.·´¯)·._.·´¯)
 ******************************
 message2
 ,.-~*´¨¯¨`*·~-.¸-(-,.-~*´¨¯¨`*·~-.¸
 ******************************
-mis_mujeres
+metal
+\m/_(>_<)_\m/
+******************************
+mis mujeres
 (-(-_(-_-)_-)-)
 ******************************
 monkey
@@ -847,6 +1390,9 @@ monster2
 mouse
 ----{,_,">
 ******************************
+nathan
+♪└(￣◇￣)┐♪└(￣◇￣)┐♪└(￣◇￣)┐♪
+******************************
 needle
 |==|iiii|>-----
 ******************************
@@ -856,16 +1402,25 @@ t(-_-t)
 nose
 \˚ㄥ˚\
 ******************************
+old lady boobs
+|\o/\o/|
+******************************
+owlkin
+(ᾢȍˬȍ)ᾢ ļ ļ ļ ļ ļ
+******************************
 panda
 ヽ(￣(ｴ)￣)ﾉ
 ******************************
+perky
+( ๏ Y ๏ )
+******************************
 pig1
 ^(*(oo)*)^
 ******************************
 pig2
 ༼☉ɷ⊙༽
 ******************************
-ping_pong
+ping pong
 ( •_•)O*¯`·.¸.·´¯`°Q(•_• )
 ******************************
 pirate
@@ -883,18 +1438,30 @@ professor
 rak
 /⦿L⦿\
 ******************************
-real_face
+rare
+┌ಠ_ಠ)┌∩┐ ᶠᶸᶜᵏ♥ᵧₒᵤ
+******************************
+real face
 ( ͡° ͜ʖ ͡°)﻿
 ******************************
+religious
+☪ ✡ † ☨ ✞ ✝ ☥ ☦ ☓ ♁ ☩
+******************************
 robot1
 d[ o_0 ]b
 ******************************
 robot2
  c[○┬●]כ
 ******************************
-rock_on
+rock on
 \,,/(^_^)\,,/
 ******************************
+rocket
+∙∙∙∙∙·▫▫ᵒᴼᵒ▫ₒₒ▫ᵒᴼᵒ▫ₒₒ▫ᵒᴼᵒ☼)===>
+******************************
+rope
+╚(▲_▲)╝
+******************************
 rose1
 --------{---(@
 ******************************
@@ -907,24 +1474,45 @@ sad1
 sad2
 (✖╭╮✖)
 ******************************
+sat
+'(◣_◢)'
+******************************
 scissors
 ✄
 ******************************
+singing
+d(^o^)b¸¸♬·¯·♩¸¸♪·¯·♫¸¸
+******************************
 sleeping
 (-.-)Zzz...
 ******************************
-sleeping_baby
+sleeping baby
 [{-_-}] ZZZzz zz z...
 ******************************
+snail
+'-'_@_
+******************************
+sniperstars
+✯╾━╤デ╦︻✯
+******************************
+sorreh bro
+(◢_◣)
+******************************
+sparkling heart
+-`ღ´-
+******************************
 sperm
 ~~o
 ******************************
-star_in_my_eyes
+star in my eyes
 <*_*>
 ******************************
 stars
 ✌⊂(✰‿✰)つ✌
 ******************************
+stars2
+⋆ ✢ ✣ ✤ ✥ ✦ ✧ ✩ ✪ ✫ ✬ ✭ ✮ ✯ ✰ ★
+******************************
 sword1
 (===||:::::::::::::::>
 ******************************
@@ -937,27 +1525,56 @@ sword3
 sword4
  |O/////[{:;:;:;:;:;:;:;:;>
 ******************************
-table_flip
+table flip
 (╯°□°）╯︵ ┻━┻
 ******************************
+teddy
+ˁ(⦿ᴥ⦿)ˀ
+******************************
+tron
+(\/)(;,,;)(\/)
+******************************
+trumpet
+-=iii=<()
+******************************
+ukulele
+{ o }==(::)
+******************************
 umadbro
 ¯\_(ツ)_/¯
 ******************************
 up
 (◔/‿\◔)
 ******************************
+upsidedown
+( ͜。 ͡ʖ ͜。)
+******************************
 waves
 °º¤ø,¸¸,ø¤º°`°º¤ø,¸,ø¤°º¤ø,¸¸,ø¤º°`°º¤ø,¸
 ******************************
+weather
+☼ ☀ ☁ ☂ ☃ ☄ ☾ ☽ ❄ ☇ ☈ ⊙ ☉ ℃ ℉ ° ❅ ✺ ϟ
+******************************
+what?
+ة_ة
+******************************
 woman
 ▓⚗_⚗▓
 ******************************
 worm
 _/\__/\__0>
 ******************************
+yolo
+Yᵒᵘ Oᶰˡʸ Lᶤᵛᵉ Oᶰᶜᵉ
+******************************
+zable
+ಠ_ರೃ
+******************************
 zombie
 'º_º'
 ******************************
+>>> aprint(artname = "awesame")
+<:3 )~~~
 >>> help_func()
               _
   __ _  _ __ | |_
@@ -966,14 +1583,20 @@ zombie
  \__,_||_|    \__|
 <BLANKLINE>
 <BLANKLINE>
-         ___       ___
-__   __ / _ \     / _ \
-\ \ / /| | | |   | (_) |
- \ V / | |_| | _  \__, |
-  \_/   \___/ (_)   /_/
+        _     ____
+__   __/ |   | ___|
+\ \ / /| |   |___ \
+ \ V / | | _  ___) |
+  \_/  |_|(_)|____/
 <BLANKLINE>
 <BLANKLINE>
+ASCII art is also known as "computer text art".
+It involves the smart placement of typed special characters or
+letters to make a visual shape that is spread over multiple lines of text.
+Art is a Python lib for text converting to ASCII ART fancy.
+<BLANKLINE>
 Webpage : http://art.shaghighi.ir
+<BLANKLINE>
 Help :
 <BLANKLINE>
      - list --> (list of arts)
@@ -991,14 +1614,22 @@ Help :
      - all 'yourtext'  -->  Example : 'python -m art all exampletext'
 >>> tprint('طط')
 <BLANKLINE>
+>>> random.seed(3)
+>>> Art = art("random")
+>>> Text = text2art("test","random")
+>>> random.seed(9)
+>>> Text2 = text2art("test","random")
+>>> Art2 =  art("random")
+>>> len(Art)!=len(Art2)
+True
+>>> len(Text)!=len(Text2)
+True
 >>> Data=art('assdsds')
 Traceback (most recent call last):
         ...
 art.art.artError: Invalid art name
 >>> art("coffee")
 'c[_] '
->>> art("love_you",number=2,text="test")
-'»-(¯`·.·´¯)->test<-(¯`·.·´¯)-« »-(¯`·.·´¯)->test<-(¯`·.·´¯)-« '
 >>> tprint("test 2")
  _               _     ____
 | |_   ___  ___ | |_  |___ \
@@ -1015,6 +1646,36 @@ art.art.artError: Invalid art name
  \__,_| \__,_||___/ \__,_| \__,_||___/ \__,_|
 <BLANKLINE>
 <BLANKLINE>
+>>> tprint("$2","block")
+<BLANKLINE>
+ .----------------.
+| .--------------. |
+| |    _____     | |
+| |   / ___ `.   | |
+| |  |_/___) |   | |
+| |   .'____.'   | |
+| |  / /____     | |
+| |  |_______|   | |
+| |              | |
+| '--------------' |
+ '----------------'
+<BLANKLINE>
+>>> tprint("salam\t","lcd")
+<BLANKLINE>
+              |
+   -   -      +    -    |- -
+   \  | |     |   | |   | | |
+   -   --     -    --
+<BLANKLINE>
+<BLANKLINE>
+>>> text2art("test",font = 2)
+Traceback (most recent call last):
+        ...
+art.art.artError: font should have str type
+>>> art("love_you",number=2,text=2)
+Traceback (most recent call last):
+        ...
+art.art.artError: text should have str type
 >>> Data=tsave("test file\nk",filename="test")
 Saved!
 Filename: test.txt
@@ -1049,14 +1710,17 @@ True
 >>> Data["Status"]
 True
 >>> file=open("test.txt","r")
->>> print(len(file.read()))
-282
+>>> data = file.read()
+>>> (len(data)==282) or (len(data)==294)
+True
 >>> file=open("art.txt","r")
->>> print(len(file.read()))
-246
+>>> data = file.read()
+>>> (len(data)==246) or (len(data)==252)
+True
 >>> file=open("art2.txt","r")
->>> print(len(file.read()))
-288
+>>> data = file.read()
+>>> (len(data)==288) or (len(data)==294)
+True
 >>> file.close()
 >>> Data=text2art(222)
 Traceback (most recent call last):
@@ -1085,7 +1749,10 @@ Traceback (most recent call last):
 art.art.artError: number should have int type
 >>> aprint("love_you",number=1,text="")
 »-(¯`·.·´¯)-><-(¯`·.·´¯)-«
->>> cov.stop()
->>> cov.save()
+>>> os.remove("art.txt")
+>>> os.remove("art2.txt")
+>>> os.remove("art3.txt")
+>>> os.remove("test.bw")
+>>> os.remove("test.txt")
 
 '''
